utils.is_grb_changed – BRDR - Aligning borders

# utils.is_grb_changed

    be.grb.utils.is_grb_changed(
        geometry,
        grb_type=GRBType.ADP,
        date_start=date.today(),
        date_end=date.today(),
        border_distance=0,
        crs=DEFAULT_CRS,
    )

checks if a geometry is possibly affected by changes in the reference layer during a specified timespan Args: geometry: Geometry to check on GRB-changes grb_type: Type of GRB (parcels, buildings,artwork,…) to check date_start: Start of timespan to check if GRB-changes has occurred date_end: End of timespan to check if GRB-changes has occurred border_distance: Distance that can be used to only check the ‘border’ of the geometry, so ‘big’ geometries with internal parcel-updates are not affected (Default:0, indicating that the full geometry is checked fot GRB-changes) crs: Coordinate reference system to use

Returns: Boolean, indicating if GRB is changed underneath the geometry